aboutsummaryrefslogtreecommitdiffstats
path: root/activesupport/lib/active_support/json
diff options
context:
space:
mode:
authorErich Menge <erich.menge@me.com>2012-05-30 11:29:09 -0500
committerErich Menge <erich.menge@me.com>2012-05-30 14:32:24 -0500
commitbcfa013399fd2c5b5d25c38912cba3560de1cc57 (patch)
tree351d5a366f9d57a61de17a7461cd26adfa0c88ec /activesupport/lib/active_support/json
parent624f801d27e946cae2244924e7f6a04565666036 (diff)
downloadrails-bcfa013399fd2c5b5d25c38912cba3560de1cc57.tar.gz
rails-bcfa013399fd2c5b5d25c38912cba3560de1cc57.tar.bz2
rails-bcfa013399fd2c5b5d25c38912cba3560de1cc57.zip
Deprecate ActiveSupport::JSON::Variable
Diffstat (limited to 'activesupport/lib/active_support/json')
-rw-r--r--activesupport/lib/active_support/json/variable.rb10
1 files changed, 9 insertions, 1 deletions
diff --git a/activesupport/lib/active_support/json/variable.rb b/activesupport/lib/active_support/json/variable.rb
index 5685ed18b7..17b709decc 100644
--- a/activesupport/lib/active_support/json/variable.rb
+++ b/activesupport/lib/active_support/json/variable.rb
@@ -1,7 +1,15 @@
+require 'active_support/deprecation'
+
module ActiveSupport
module JSON
# A string that returns itself as its JSON-encoded form.
class Variable < String
+ def initialize(*args)
+ ActiveSupport::Deprecation.warn 'ActiveSupport::JSON::Variable is deprecated and will be removed in Rails 4.0. ' \
+ 'For your own custom JSON literals, define #as_json and #encode_json yourself.'
+ super
+ end
+
def as_json(options = nil) self end #:nodoc:
def encode_json(encoder) self end #:nodoc:
end
@@ -1,7 +1,15 @@
module ActiveSupport
module JSON
- # A string that returns itself as its JSON-encoded form.
+ # Deprecated: A string that returns itself as its JSON-encoded form.
class Variable < String